pb

package
v0.7.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 14, 2025 License: MIT Imports: 11 Imported by: 0

Documentation

Index

Constants

const (
	SubscriptionService_GetAccountCredits_FullMethodName = "/billing.SubscriptionService/GetAccountCredits"
	SubscriptionService_AllocateCredits_FullMethodName   = "/billing.SubscriptionService/AllocateCredits"
	SubscriptionService_BillAccount_FullMethodName       = "/billing.SubscriptionService/BillAccount"
)
const (
	WorkflowService_GetAccountCredits_FullMethodName          = "/billing.WorkflowService/GetAccountCredits"
	WorkflowService_BatchGetCreditsForAccounts_FullMethodName = "/billing.WorkflowService/BatchGetCreditsForAccounts"
	WorkflowService_ReserveCredits_FullMethodName             = "/billing.WorkflowService/ReserveCredits"
	WorkflowService_ReleaseReservation_FullMethodName         = "/billing.WorkflowService/ReleaseReservation"
	WorkflowService_ConsumeCredits_FullMethodName             = "/billing.WorkflowService/ConsumeCredits"
	WorkflowService_ConsumeReservation_FullMethodName         = "/billing.WorkflowService/ConsumeReservation"
	WorkflowService_WorkflowReceipt_FullMethodName            = "/billing.WorkflowService/WorkflowReceipt"
)

Variables

var File_billing_pb_billing_service_proto protoreflect.FileDescriptor
var SubscriptionService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "billing.SubscriptionService",
	HandlerType: (*SubscriptionServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetAccountCredits",
			Handler:    _SubscriptionService_GetAccountCredits_Handler,
		},
		{
			MethodName: "AllocateCredits",
			Handler:    _SubscriptionService_AllocateCredits_Handler,
		},
		{
			MethodName: "BillAccount",
			Handler:    _SubscriptionService_BillAccount_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "billing/pb/billing_service.proto",
}

SubscriptionService_ServiceDesc is the grpc.ServiceDesc for SubscriptionService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var WorkflowService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "billing.WorkflowService",
	HandlerType: (*WorkflowServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetAccountCredits",
			Handler:    _WorkflowService_GetAccountCredits_Handler,
		},
		{
			MethodName: "BatchGetCreditsForAccounts",
			Handler:    _WorkflowService_BatchGetCreditsForAccounts_Handler,
		},
		{
			MethodName: "ReserveCredits",
			Handler:    _WorkflowService_ReserveCredits_Handler,
		},
		{
			MethodName: "ReleaseReservation",
			Handler:    _WorkflowService_ReleaseReservation_Handler,
		},
		{
			MethodName: "ConsumeCredits",
			Handler:    _WorkflowService_ConsumeCredits_Handler,
		},
		{
			MethodName: "ConsumeReservation",
			Handler:    _WorkflowService_ConsumeReservation_Handler,
		},
		{
			MethodName: "WorkflowReceipt",
			Handler:    _WorkflowService_WorkflowReceipt_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "billing/pb/billing_service.proto",
}

WorkflowService_ServiceDesc is the grpc.ServiceDesc for WorkflowService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterSubscriptionServiceServer

func RegisterSubscriptionServiceServer(s grpc.ServiceRegistrar, srv SubscriptionServiceServer)

func RegisterWorkflowServiceServer

func RegisterWorkflowServiceServer(s grpc.ServiceRegistrar, srv WorkflowServiceServer)

Types

type AccountCredits

type AccountCredits struct {
	Credits         float32                `protobuf:"fixed32,1,opt,name=credits,proto3" json:"credits,omitempty"`
	CreditsReserved float32                `protobuf:"fixed32,2,opt,name=credits_reserved,json=creditsReserved,proto3" json:"credits_reserved,omitempty"`
	CreditType      string                 `protobuf:"bytes,3,opt,name=credit_type,json=creditType,proto3" json:"credit_type,omitempty"` // TODO make ENUM
	CreatedAt       *timestamppb.Timestamp `protobuf:"bytes,4,opt,name=created_at,json=createdAt,proto3" json:"created_at,omitempty"`
	UpdatedAt       *timestamppb.Timestamp `protobuf:"bytes,5,opt,name=updated_at,json=updatedAt,proto3" json:"updated_at,omitempty"`
	// contains filtered or unexported fields
}

func (*AccountCredits) Descriptor deprecated

func (*AccountCredits) Descriptor() ([]byte, []int)

Deprecated: Use AccountCredits.ProtoReflect.Descriptor instead.

func (*AccountCredits) GetCreatedAt

func (x *AccountCredits) GetCreatedAt() *timestamppb.Timestamp

func (*AccountCredits) GetCreditType

func (x *AccountCredits) GetCreditType() string

func (*AccountCredits) GetCredits

func (x *AccountCredits) GetCredits() float32

func (*AccountCredits) GetCreditsReserved

func (x *AccountCredits) GetCreditsReserved() float32

func (*AccountCredits) GetUpdatedAt

func (x *AccountCredits) GetUpdatedAt() *timestamppb.Timestamp

func (*AccountCredits) ProtoMessage

func (*AccountCredits) ProtoMessage()

func (*AccountCredits) ProtoReflect

func (x *AccountCredits) ProtoReflect() protoreflect.Message

func (*AccountCredits) Reset

func (x *AccountCredits) Reset()

func (*AccountCredits) String

func (x *AccountCredits) String() string

type AccountCreditsInput

type AccountCreditsInput struct {
	Credits    float32 `protobuf:"fixed32,1,opt,name=credits,proto3" json:"credits,omitempty"`
	CreditType string  `protobuf:"bytes,2,opt,name=credit_type,json=creditType,proto3" json:"credit_type,omitempty"` // TODO make ENUM
	// contains filtered or unexported fields
}

func (*AccountCreditsInput) Descriptor deprecated

func (*AccountCreditsInput) Descriptor() ([]byte, []int)

Deprecated: Use AccountCreditsInput.ProtoReflect.Descriptor instead.

func (*AccountCreditsInput) GetCreditType

func (x *AccountCreditsInput) GetCreditType() string

func (*AccountCreditsInput) GetCredits

func (x *AccountCreditsInput) GetCredits() float32

func (*AccountCreditsInput) ProtoMessage

func (*AccountCreditsInput) ProtoMessage()

func (*AccountCreditsInput) ProtoReflect

func (x *AccountCreditsInput) ProtoReflect() protoreflect.Message

func (*AccountCreditsInput) Reset

func (x *AccountCreditsInput) Reset()

func (*AccountCreditsInput) String

func (x *AccountCreditsInput) String() string

type AccountWithCredits

type AccountWithCredits struct {
	AccountId string            `protobuf:"bytes,1,opt,name=account_id,json=accountId,proto3" json:"account_id,omitempty"`
	Credits   []*AccountCredits `protobuf:"bytes,2,rep,name=credits,proto3" json:"credits,omitempty"`
	// contains filtered or unexported fields
}

func (*AccountWithCredits) Descriptor deprecated

func (*AccountWithCredits) Descriptor() ([]byte, []int)

Deprecated: Use AccountWithCredits.ProtoReflect.Descriptor instead.

func (*AccountWithCredits) GetAccountId

func (x *AccountWithCredits) GetAccountId() string

func (*AccountWithCredits) GetCredits

func (x *AccountWithCredits) GetCredits() []*AccountCredits

func (*AccountWithCredits) ProtoMessage

func (*AccountWithCredits) ProtoMessage()

func (*AccountWithCredits) ProtoReflect

func (x *AccountWithCredits) ProtoReflect() protoreflect.Message

func (*AccountWithCredits) Reset

func (x *AccountWithCredits) Reset()

func (*AccountWithCredits) String

func (x *AccountWithCredits) String() string

type AllocateCreditsRequest

type AllocateCreditsRequest struct {
	AccountId string                 `protobuf:"bytes,1,opt,name=account_id,json=accountId,proto3" json:"account_id,omitempty"`
	Credits   []*AccountCreditsInput `protobuf:"bytes,2,rep,name=credits,proto3" json:"credits,omitempty"`
	// contains filtered or unexported fields
}

func (*AllocateCreditsRequest) Descriptor deprecated

func (*AllocateCreditsRequest) Descriptor() ([]byte, []int)

Deprecated: Use AllocateCreditsRequest.ProtoReflect.Descriptor instead.

func (*AllocateCreditsRequest) GetAccountId

func (x *AllocateCreditsRequest) GetAccountId() string

func (*AllocateCreditsRequest) GetCredits

func (x *AllocateCreditsRequest) GetCredits() []*AccountCreditsInput

func (*AllocateCreditsRequest) ProtoMessage

func (*AllocateCreditsRequest) ProtoMessage()

func (*AllocateCreditsRequest) ProtoReflect

func (x *AllocateCreditsRequest) ProtoReflect() protoreflect.Message

func (*AllocateCreditsRequest) Reset

func (x *AllocateCreditsRequest) Reset()

func (*AllocateCreditsRequest) String

func (x *AllocateCreditsRequest) String() string

type AllocateCreditsResponse

type AllocateCreditsResponse struct {
	Success bool `protobuf:"varint,1,opt,name=Success,proto3" json:"Success,omitempty"`
	// contains filtered or unexported fields
}

func (*AllocateCreditsResponse) Descriptor deprecated

func (*AllocateCreditsResponse) Descriptor() ([]byte, []int)

Deprecated: Use AllocateCreditsResponse.ProtoReflect.Descriptor instead.

func (*AllocateCreditsResponse) GetSuccess

func (x *AllocateCreditsResponse) GetSuccess() bool

func (*AllocateCreditsResponse) ProtoMessage

func (*AllocateCreditsResponse) ProtoMessage()

func (*AllocateCreditsResponse) ProtoReflect

func (x *AllocateCreditsResponse) ProtoReflect() protoreflect.Message

func (*AllocateCreditsResponse) Reset

func (x *AllocateCreditsResponse) Reset()

func (*AllocateCreditsResponse) String

func (x *AllocateCreditsResponse) String() string

type BatchGetCreditsForAccountsRequest

type BatchGetCreditsForAccountsRequest struct {
	AccountIds []string `protobuf:"bytes,1,rep,name=account_ids,json=accountIds,proto3" json:"account_ids,omitempty"`
	// contains filtered or unexported fields
}

func (*BatchGetCreditsForAccountsRequest) Descriptor deprecated

func (*BatchGetCreditsForAccountsRequest) Descriptor() ([]byte, []int)

Deprecated: Use BatchGetCreditsForAccountsRequest.ProtoReflect.Descriptor instead.

func (*BatchGetCreditsForAccountsRequest) GetAccountIds

func (x *BatchGetCreditsForAccountsRequest) GetAccountIds() []string

func (*BatchGetCreditsForAccountsRequest) ProtoMessage

func (*BatchGetCreditsForAccountsRequest) ProtoMessage()

func (*BatchGetCreditsForAccountsRequest) ProtoReflect

func (*BatchGetCreditsForAccountsRequest) Reset

func (*BatchGetCreditsForAccountsRequest) String

type BatchGetCreditsForAccountsResponse

type BatchGetCreditsForAccountsResponse struct {
	Accounts []*AccountWithCredits `protobuf:"bytes,1,rep,name=accounts,proto3" json:"accounts,omitempty"`
	// contains filtered or unexported fields
}

func (*BatchGetCreditsForAccountsResponse) Descriptor deprecated

func (*BatchGetCreditsForAccountsResponse) Descriptor() ([]byte, []int)

Deprecated: Use BatchGetCreditsForAccountsResponse.ProtoReflect.Descriptor instead.

func (*BatchGetCreditsForAccountsResponse) GetAccounts

func (*BatchGetCreditsForAccountsResponse) ProtoMessage

func (*BatchGetCreditsForAccountsResponse) ProtoMessage()

func (*BatchGetCreditsForAccountsResponse) ProtoReflect

func (*BatchGetCreditsForAccountsResponse) Reset

func (*BatchGetCreditsForAccountsResponse) String

type BillAccountRequest

type BillAccountRequest struct {
	AccountId      string  `protobuf:"bytes,1,opt,name=account_id,json=accountId,proto3" json:"account_id,omitempty"`
	Amt            float32 `protobuf:"fixed32,2,opt,name=amt,proto3" json:"amt,omitempty"`
	Currency       string  `protobuf:"bytes,3,opt,name=currency,proto3" json:"currency,omitempty"`
	IdempotencyKey string  `protobuf:"bytes,4,opt,name=idempotency_key,json=idempotencyKey,proto3" json:"idempotency_key,omitempty"`
	// contains filtered or unexported fields
}

func (*BillAccountRequest) Descriptor deprecated

func (*BillAccountRequest) Descriptor() ([]byte, []int)

Deprecated: Use BillAccountRequest.ProtoReflect.Descriptor instead.

func (*BillAccountRequest) GetAccountId

func (x *BillAccountRequest) GetAccountId() string

func (*BillAccountRequest) GetAmt

func (x *BillAccountRequest) GetAmt() float32

func (*BillAccountRequest) GetCurrency

func (x *BillAccountRequest) GetCurrency() string

func (*BillAccountRequest) GetIdempotencyKey

func (x *BillAccountRequest) GetIdempotencyKey() string

func (*BillAccountRequest) ProtoMessage

func (*BillAccountRequest) ProtoMessage()

func (*BillAccountRequest) ProtoReflect

func (x *BillAccountRequest) ProtoReflect() protoreflect.Message

func (*BillAccountRequest) Reset

func (x *BillAccountRequest) Reset()

func (*BillAccountRequest) String

func (x *BillAccountRequest) String() string

type BillAccountResponse

type BillAccountResponse struct {
	BillId string `protobuf:"bytes,1,opt,name=bill_id,json=billId,proto3" json:"bill_id,omitempty"`
	// contains filtered or unexported fields
}

func (*BillAccountResponse) Descriptor deprecated

func (*BillAccountResponse) Descriptor() ([]byte, []int)

Deprecated: Use BillAccountResponse.ProtoReflect.Descriptor instead.

func (*BillAccountResponse) GetBillId

func (x *BillAccountResponse) GetBillId() string

func (*BillAccountResponse) ProtoMessage

func (*BillAccountResponse) ProtoMessage()

func (*BillAccountResponse) ProtoReflect

func (x *BillAccountResponse) ProtoReflect() protoreflect.Message

func (*BillAccountResponse) Reset

func (x *BillAccountResponse) Reset()

func (*BillAccountResponse) String

func (x *BillAccountResponse) String() string

type ConsumeCreditsRequest

type ConsumeCreditsRequest struct {
	AccountId  string                 `protobuf:"bytes,1,opt,name=account_id,json=accountId,proto3" json:"account_id,omitempty"`
	WorkflowId string                 `protobuf:"bytes,2,opt,name=workflow_id,json=workflowId,proto3" json:"workflow_id,omitempty"`
	Credits    []*AccountCreditsInput `protobuf:"bytes,3,rep,name=credits,proto3" json:"credits,omitempty"`
	// contains filtered or unexported fields
}

func (*ConsumeCreditsRequest) Descriptor deprecated

func (*ConsumeCreditsRequest) Descriptor() ([]byte, []int)

Deprecated: Use ConsumeCreditsRequest.ProtoReflect.Descriptor instead.

func (*ConsumeCreditsRequest) GetAccountId

func (x *ConsumeCreditsRequest) GetAccountId() string

func (*ConsumeCreditsRequest) GetCredits

func (x *ConsumeCreditsRequest) GetCredits() []*AccountCreditsInput

func (*ConsumeCreditsRequest) GetWorkflowId

func (x *ConsumeCreditsRequest) GetWorkflowId() string

func (*ConsumeCreditsRequest) ProtoMessage

func (*ConsumeCreditsRequest) ProtoMessage()

func (*ConsumeCreditsRequest) ProtoReflect

func (x *ConsumeCreditsRequest) ProtoReflect() protoreflect.Message

func (*ConsumeCreditsRequest) Reset

func (x *ConsumeCreditsRequest) Reset()

func (*ConsumeCreditsRequest) String

func (x *ConsumeCreditsRequest) String() string

type ConsumeCreditsResponse

type ConsumeCreditsResponse struct {
	Success bool `protobuf:"varint,1,opt,name=success,proto3" json:"success,omitempty"`
	// contains filtered or unexported fields
}

func (*ConsumeCreditsResponse) Descriptor deprecated

func (*ConsumeCreditsResponse) Descriptor() ([]byte, []int)

Deprecated: Use ConsumeCreditsResponse.ProtoReflect.Descriptor instead.

func (*ConsumeCreditsResponse) GetSuccess

func (x *ConsumeCreditsResponse) GetSuccess() bool

func (*ConsumeCreditsResponse) ProtoMessage

func (*ConsumeCreditsResponse) ProtoMessage()

func (*ConsumeCreditsResponse) ProtoReflect

func (x *ConsumeCreditsResponse) ProtoReflect() protoreflect.Message

func (*ConsumeCreditsResponse) Reset

func (x *ConsumeCreditsResponse) Reset()

func (*ConsumeCreditsResponse) String

func (x *ConsumeCreditsResponse) String() string

type ConsumeReservationRequest

type ConsumeReservationRequest struct {
	AccountId           string `protobuf:"bytes,1,opt,name=account_id,json=accountId,proto3" json:"account_id,omitempty"`
	WorkflowId          string `protobuf:"bytes,2,opt,name=workflow_id,json=workflowId,proto3" json:"workflow_id,omitempty"`
	WorkflowExecutionId string `protobuf:"bytes,3,opt,name=workflow_execution_id,json=workflowExecutionId,proto3" json:"workflow_execution_id,omitempty"`
	// contains filtered or unexported fields
}

func (*ConsumeReservationRequest) Descriptor deprecated

func (*ConsumeReservationRequest) Descriptor() ([]byte, []int)

Deprecated: Use ConsumeReservationRequest.ProtoReflect.Descriptor instead.

func (*ConsumeReservationRequest) GetAccountId

func (x *ConsumeReservationRequest) GetAccountId() string

func (*ConsumeReservationRequest) GetWorkflowExecutionId

func (x *ConsumeReservationRequest) GetWorkflowExecutionId() string

func (*ConsumeReservationRequest) GetWorkflowId

func (x *ConsumeReservationRequest) GetWorkflowId() string

func (*ConsumeReservationRequest) ProtoMessage

func (*ConsumeReservationRequest) ProtoMessage()

func (*ConsumeReservationRequest) ProtoReflect

func (*ConsumeReservationRequest) Reset

func (x *ConsumeReservationRequest) Reset()

func (*ConsumeReservationRequest) String

func (x *ConsumeReservationRequest) String() string

type ConsumeReservationResponse

type ConsumeReservationResponse struct {
	Success bool `protobuf:"varint,1,opt,name=success,proto3" json:"success,omitempty"`
	// contains filtered or unexported fields
}

func (*ConsumeReservationResponse) Descriptor deprecated

func (*ConsumeReservationResponse) Descriptor() ([]byte, []int)

Deprecated: Use ConsumeReservationResponse.ProtoReflect.Descriptor instead.

func (*ConsumeReservationResponse) GetSuccess

func (x *ConsumeReservationResponse) GetSuccess() bool

func (*ConsumeReservationResponse) ProtoMessage

func (*ConsumeReservationResponse) ProtoMessage()

func (*ConsumeReservationResponse) ProtoReflect

func (*ConsumeReservationResponse) Reset

func (x *ConsumeReservationResponse) Reset()

func (*ConsumeReservationResponse) String

func (x *ConsumeReservationResponse) String() string

type EmptyRequest

type EmptyRequest struct {
	// contains filtered or unexported fields
}

func (*EmptyRequest) Descriptor deprecated

func (*EmptyRequest) Descriptor() ([]byte, []int)

Deprecated: Use EmptyRequest.ProtoReflect.Descriptor instead.

func (*EmptyRequest) ProtoMessage

func (*EmptyRequest) ProtoMessage()

func (*EmptyRequest) ProtoReflect

func (x *EmptyRequest) ProtoReflect() protoreflect.Message

func (*EmptyRequest) Reset

func (x *EmptyRequest) Reset()

func (*EmptyRequest) String

func (x *EmptyRequest) String() string

type EmptyResponse

type EmptyResponse struct {
	Message string `protobuf:"bytes,1,opt,name=message,proto3" json:"message,omitempty"`
	// contains filtered or unexported fields
}

func (*EmptyResponse) Descriptor deprecated

func (*EmptyResponse) Descriptor() ([]byte, []int)

Deprecated: Use EmptyResponse.ProtoReflect.Descriptor instead.

func (*EmptyResponse) GetMessage

func (x *EmptyResponse) GetMessage() string

func (*EmptyResponse) ProtoMessage

func (*EmptyResponse) ProtoMessage()

func (*EmptyResponse) ProtoReflect

func (x *EmptyResponse) ProtoReflect() protoreflect.Message

func (*EmptyResponse) Reset

func (x *EmptyResponse) Reset()

func (*EmptyResponse) String

func (x *EmptyResponse) String() string

type GetAccountCreditsRequest

type GetAccountCreditsRequest struct {
	AccountId string `protobuf:"bytes,1,opt,name=account_id,json=accountId,proto3" json:"account_id,omitempty"`
	// contains filtered or unexported fields
}

func (*GetAccountCreditsRequest) Descriptor deprecated

func (*GetAccountCreditsRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetAccountCreditsRequest.ProtoReflect.Descriptor instead.

func (*GetAccountCreditsRequest) GetAccountId

func (x *GetAccountCreditsRequest) GetAccountId() string

func (*GetAccountCreditsRequest) ProtoMessage

func (*GetAccountCreditsRequest) ProtoMessage()

func (*GetAccountCreditsRequest) ProtoReflect

func (x *GetAccountCreditsRequest) ProtoReflect() protoreflect.Message

func (*GetAccountCreditsRequest) Reset

func (x *GetAccountCreditsRequest) Reset()

func (*GetAccountCreditsRequest) String

func (x *GetAccountCreditsRequest) String() string

type GetAccountCreditsResponse

type GetAccountCreditsResponse struct {
	AccountId string            `protobuf:"bytes,1,opt,name=account_id,json=accountId,proto3" json:"account_id,omitempty"`
	Credits   []*AccountCredits `protobuf:"bytes,2,rep,name=credits,proto3" json:"credits,omitempty"`
	// contains filtered or unexported fields
}

func (*GetAccountCreditsResponse) Descriptor deprecated

func (*GetAccountCreditsResponse) Descriptor() ([]byte, []int)

Deprecated: Use GetAccountCreditsResponse.ProtoReflect.Descriptor instead.

func (*GetAccountCreditsResponse) GetAccountId

func (x *GetAccountCreditsResponse) GetAccountId() string

func (*GetAccountCreditsResponse) GetCredits

func (x *GetAccountCreditsResponse) GetCredits() []*AccountCredits

func (*GetAccountCreditsResponse) ProtoMessage

func (*GetAccountCreditsResponse) ProtoMessage()

func (*GetAccountCreditsResponse) ProtoReflect

func (*GetAccountCreditsResponse) Reset

func (x *GetAccountCreditsResponse) Reset()

func (*GetAccountCreditsResponse) String

func (x *GetAccountCreditsResponse) String() string

type ReleaseReservationRequest

type ReleaseReservationRequest struct {
	AccountId           string `protobuf:"bytes,1,opt,name=account_id,json=accountId,proto3" json:"account_id,omitempty"`
	WorkflowId          string `protobuf:"bytes,2,opt,name=workflow_id,json=workflowId,proto3" json:"workflow_id,omitempty"`
	WorkflowExecutionId string `protobuf:"bytes,3,opt,name=workflow_execution_id,json=workflowExecutionId,proto3" json:"workflow_execution_id,omitempty"`
	// contains filtered or unexported fields
}

func (*ReleaseReservationRequest) Descriptor deprecated

func (*ReleaseReservationRequest) Descriptor() ([]byte, []int)

Deprecated: Use ReleaseReservationRequest.ProtoReflect.Descriptor instead.

func (*ReleaseReservationRequest) GetAccountId

func (x *ReleaseReservationRequest) GetAccountId() string

func (*ReleaseReservationRequest) GetWorkflowExecutionId

func (x *ReleaseReservationRequest) GetWorkflowExecutionId() string

func (*ReleaseReservationRequest) GetWorkflowId

func (x *ReleaseReservationRequest) GetWorkflowId() string

func (*ReleaseReservationRequest) ProtoMessage

func (*ReleaseReservationRequest) ProtoMessage()

func (*ReleaseReservationRequest) ProtoReflect

func (*ReleaseReservationRequest) Reset

func (x *ReleaseReservationRequest) Reset()

func (*ReleaseReservationRequest) String

func (x *ReleaseReservationRequest) String() string

type ReleaseReservationResponse

type ReleaseReservationResponse struct {
	Success bool `protobuf:"varint,1,opt,name=success,proto3" json:"success,omitempty"`
	// contains filtered or unexported fields
}

func (*ReleaseReservationResponse) Descriptor deprecated

func (*ReleaseReservationResponse) Descriptor() ([]byte, []int)

Deprecated: Use ReleaseReservationResponse.ProtoReflect.Descriptor instead.

func (*ReleaseReservationResponse) GetSuccess

func (x *ReleaseReservationResponse) GetSuccess() bool

func (*ReleaseReservationResponse) ProtoMessage

func (*ReleaseReservationResponse) ProtoMessage()

func (*ReleaseReservationResponse) ProtoReflect

func (*ReleaseReservationResponse) Reset

func (x *ReleaseReservationResponse) Reset()

func (*ReleaseReservationResponse) String

func (x *ReleaseReservationResponse) String() string

type ReserveCreditsRequest

type ReserveCreditsRequest struct {
	AccountId           string                 `protobuf:"bytes,1,opt,name=account_id,json=accountId,proto3" json:"account_id,omitempty"`
	WorkflowId          string                 `protobuf:"bytes,2,opt,name=workflow_id,json=workflowId,proto3" json:"workflow_id,omitempty"`
	WorkflowExecutionId string                 `protobuf:"bytes,3,opt,name=workflow_execution_id,json=workflowExecutionId,proto3" json:"workflow_execution_id,omitempty"`
	Credits             []*AccountCreditsInput `protobuf:"bytes,4,rep,name=credits,proto3" json:"credits,omitempty"`
	// contains filtered or unexported fields
}

Reserve/Consume messages

func (*ReserveCreditsRequest) Descriptor deprecated

func (*ReserveCreditsRequest) Descriptor() ([]byte, []int)

Deprecated: Use ReserveCreditsRequest.ProtoReflect.Descriptor instead.

func (*ReserveCreditsRequest) GetAccountId

func (x *ReserveCreditsRequest) GetAccountId() string

func (*ReserveCreditsRequest) GetCredits

func (x *ReserveCreditsRequest) GetCredits() []*AccountCreditsInput

func (*ReserveCreditsRequest) GetWorkflowExecutionId

func (x *ReserveCreditsRequest) GetWorkflowExecutionId() string

func (*ReserveCreditsRequest) GetWorkflowId

func (x *ReserveCreditsRequest) GetWorkflowId() string

func (*ReserveCreditsRequest) ProtoMessage

func (*ReserveCreditsRequest) ProtoMessage()

func (*ReserveCreditsRequest) ProtoReflect

func (x *ReserveCreditsRequest) ProtoReflect() protoreflect.Message

func (*ReserveCreditsRequest) Reset

func (x *ReserveCreditsRequest) Reset()

func (*ReserveCreditsRequest) String

func (x *ReserveCreditsRequest) String() string

type ReserveCreditsResponse

type ReserveCreditsResponse struct {
	Success bool `protobuf:"varint,1,opt,name=success,proto3" json:"success,omitempty"`
	// contains filtered or unexported fields
}

func (*ReserveCreditsResponse) Descriptor deprecated

func (*ReserveCreditsResponse) Descriptor() ([]byte, []int)

Deprecated: Use ReserveCreditsResponse.ProtoReflect.Descriptor instead.

func (*ReserveCreditsResponse) GetSuccess

func (x *ReserveCreditsResponse) GetSuccess() bool

func (*ReserveCreditsResponse) ProtoMessage

func (*ReserveCreditsResponse) ProtoMessage()

func (*ReserveCreditsResponse) ProtoReflect

func (x *ReserveCreditsResponse) ProtoReflect() protoreflect.Message

func (*ReserveCreditsResponse) Reset

func (x *ReserveCreditsResponse) Reset()

func (*ReserveCreditsResponse) String

func (x *ReserveCreditsResponse) String() string

type SubmitWorkflowReceiptRequest

type SubmitWorkflowReceiptRequest struct {
	AccountId           string             `protobuf:"bytes,1,opt,name=account_id,json=accountId,proto3" json:"account_id,omitempty"`
	WorkflowId          string             `protobuf:"bytes,2,opt,name=workflow_id,json=workflowId,proto3" json:"workflow_id,omitempty"`
	WorkflowExecutionId string             `protobuf:"bytes,3,opt,name=workflow_execution_id,json=workflowExecutionId,proto3" json:"workflow_execution_id,omitempty"`
	Metering            *pb.MeteringReport `protobuf:"bytes,4,opt,name=metering,proto3" json:"metering,omitempty"`
	// contains filtered or unexported fields
}

func (*SubmitWorkflowReceiptRequest) Descriptor deprecated

func (*SubmitWorkflowReceiptRequest) Descriptor() ([]byte, []int)

Deprecated: Use SubmitWorkflowReceiptRequest.ProtoReflect.Descriptor instead.

func (*SubmitWorkflowReceiptRequest) GetAccountId

func (x *SubmitWorkflowReceiptRequest) GetAccountId() string

func (*SubmitWorkflowReceiptRequest) GetMetering

func (*SubmitWorkflowReceiptRequest) GetWorkflowExecutionId

func (x *SubmitWorkflowReceiptRequest) GetWorkflowExecutionId() string

func (*SubmitWorkflowReceiptRequest) GetWorkflowId

func (x *SubmitWorkflowReceiptRequest) GetWorkflowId() string

func (*SubmitWorkflowReceiptRequest) ProtoMessage

func (*SubmitWorkflowReceiptRequest) ProtoMessage()

func (*SubmitWorkflowReceiptRequest) ProtoReflect

func (*SubmitWorkflowReceiptRequest) Reset

func (x *SubmitWorkflowReceiptRequest) Reset()

func (*SubmitWorkflowReceiptRequest) String

type SubmitWorkflowReceiptResponse

type SubmitWorkflowReceiptResponse struct {
	Success bool `protobuf:"varint,1,opt,name=success,proto3" json:"success,omitempty"`
	// contains filtered or unexported fields
}

func (*SubmitWorkflowReceiptResponse) Descriptor deprecated

func (*SubmitWorkflowReceiptResponse) Descriptor() ([]byte, []int)

Deprecated: Use SubmitWorkflowReceiptResponse.ProtoReflect.Descriptor instead.

func (*SubmitWorkflowReceiptResponse) GetSuccess

func (x *SubmitWorkflowReceiptResponse) GetSuccess() bool

func (*SubmitWorkflowReceiptResponse) ProtoMessage

func (*SubmitWorkflowReceiptResponse) ProtoMessage()

func (*SubmitWorkflowReceiptResponse) ProtoReflect

func (*SubmitWorkflowReceiptResponse) Reset

func (x *SubmitWorkflowReceiptResponse) Reset()

func (*SubmitWorkflowReceiptResponse) String

type SubscriptionServiceClient

type SubscriptionServiceClient interface {
	GetAccountCredits(ctx context.Context, in *GetAccountCreditsRequest, opts ...grpc.CallOption) (*GetAccountCreditsResponse, error)
	AllocateCredits(ctx context.Context, in *AllocateCreditsRequest, opts ...grpc.CallOption) (*AllocateCreditsResponse, error)
	BillAccount(ctx context.Context, in *BillAccountRequest, opts ...grpc.CallOption) (*BillAccountResponse, error)
}

SubscriptionServiceClient is the client API for SubscriptionService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

SubscriptionService

type SubscriptionServiceServer

type SubscriptionServiceServer interface {
	GetAccountCredits(context.Context, *GetAccountCreditsRequest) (*GetAccountCreditsResponse, error)
	AllocateCredits(context.Context, *AllocateCreditsRequest) (*AllocateCreditsResponse, error)
	BillAccount(context.Context, *BillAccountRequest) (*BillAccountResponse, error)
	// contains filtered or unexported methods
}

SubscriptionServiceServer is the server API for SubscriptionService service. All implementations must embed UnimplementedSubscriptionServiceServer for forward compatibility.

SubscriptionService

type UnimplementedSubscriptionServiceServer

type UnimplementedSubscriptionServiceServer struct{}

UnimplementedSubscriptionServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedSubscriptionServiceServer) AllocateCredits

func (UnimplementedSubscriptionServiceServer) BillAccount

func (UnimplementedSubscriptionServiceServer) GetAccountCredits

type UnimplementedWorkflowServiceServer

type UnimplementedWorkflowServiceServer struct{}

UnimplementedWorkflowServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedWorkflowServiceServer) ConsumeCredits

func (UnimplementedWorkflowServiceServer) ConsumeReservation

func (UnimplementedWorkflowServiceServer) GetAccountCredits

func (UnimplementedWorkflowServiceServer) ReleaseReservation

func (UnimplementedWorkflowServiceServer) ReserveCredits

type UnsafeSubscriptionServiceServer

type UnsafeSubscriptionServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeSubscriptionServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to SubscriptionServiceServer will result in compilation errors.

type UnsafeWorkflowServiceServer

type UnsafeWorkflowServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeWorkflowServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to WorkflowServiceServer will result in compilation errors.

type WorkflowServiceClient

WorkflowServiceClient is the client API for WorkflowService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

WorkflowService

type WorkflowServiceServer

WorkflowServiceServer is the server API for WorkflowService service. All implementations must embed UnimplementedWorkflowServiceServer for forward compatibility.

WorkflowService

Jump to