Documentation
¶
Index ¶
- type MockExecutionHelper
- func (_m *MockExecutionHelper) CallCapability(ctx context.Context, request *sdk.CapabilityRequest) (*sdk.CapabilityResponse, error)
- func (_m *MockExecutionHelper) EXPECT() *MockExecutionHelper_Expecter
- func (_m *MockExecutionHelper) EmitUserLog(log string) error
- func (_m *MockExecutionHelper) EmitUserMetric(ctx context.Context, metric *v2.WorkflowUserMetric) error
- func (_m *MockExecutionHelper) GetDONTime() (time.Time, error)
- func (_m *MockExecutionHelper) GetNodeTime() time.Time
- func (_m *MockExecutionHelper) GetSecrets(ctx context.Context, request *sdk.GetSecretsRequest) ([]*sdk.SecretResponse, error)
- func (_m *MockExecutionHelper) GetWorkflowExecutionID() string
- type MockExecutionHelperWithRawSecrets
- func (_m *MockExecutionHelperWithRawSecrets) CallCapability(ctx context.Context, request *sdk.CapabilityRequest) (*sdk.CapabilityResponse, error)
- func (_m *MockExecutionHelperWithRawSecrets) EXPECT() *MockExecutionHelperWithRawSecrets_Expecter
- func (_m *MockExecutionHelperWithRawSecrets) EmitUserLog(log string) error
- func (_m *MockExecutionHelperWithRawSecrets) EmitUserMetric(ctx context.Context, metric *v2.WorkflowUserMetric) error
- func (_m *MockExecutionHelperWithRawSecrets) GetDONTime() (time.Time, error)
- func (_m *MockExecutionHelperWithRawSecrets) GetNodeTime() time.Time
- func (_m *MockExecutionHelperWithRawSecrets) GetOwner() string
- func (_m *MockExecutionHelperWithRawSecrets) GetRawSecrets(ctx context.Context, request *sdk.GetSecretsRequest, ...) ([]*vault.SecretResponse, error)
- func (_m *MockExecutionHelperWithRawSecrets) GetSecrets(ctx context.Context, request *sdk.GetSecretsRequest) ([]*sdk.SecretResponse, error)
- func (_m *MockExecutionHelperWithRawSecrets) GetWorkflowExecutionID() string
- type MockExecutionHelperWithRawSecrets_CallCapability_Call
- func (_c *MockExecutionHelperWithRawSecrets_CallCapability_Call) Return(_a0 *sdk.CapabilityResponse, _a1 error) *MockExecutionHelperWithRawSecrets_CallCapability_Call
- func (_c *MockExecutionHelperWithRawSecrets_CallCapability_Call) Run(run func(ctx context.Context, request *sdk.CapabilityRequest)) *MockExecutionHelperWithRawSecrets_CallCapability_Call
- func (_c *MockExecutionHelperWithRawSecrets_CallCapability_Call) RunAndReturn(...) *MockExecutionHelperWithRawSecrets_CallCapability_Call
- type MockExecutionHelperWithRawSecrets_EmitUserLog_Call
- func (_c *MockExecutionHelperWithRawSecrets_EmitUserLog_Call) Return(_a0 error) *MockExecutionHelperWithRawSecrets_EmitUserLog_Call
- func (_c *MockExecutionHelperWithRawSecrets_EmitUserLog_Call) Run(run func(log string)) *MockExecutionHelperWithRawSecrets_EmitUserLog_Call
- func (_c *MockExecutionHelperWithRawSecrets_EmitUserLog_Call) RunAndReturn(run func(string) error) *MockExecutionHelperWithRawSecrets_EmitUserLog_Call
- type MockExecutionHelperWithRawSecrets_EmitUserMetric_Call
- func (_c *MockExecutionHelperWithRawSecrets_EmitUserMetric_Call) Return(_a0 error) *MockExecutionHelperWithRawSecrets_EmitUserMetric_Call
- func (_c *MockExecutionHelperWithRawSecrets_EmitUserMetric_Call) Run(run func(ctx context.Context, metric *v2.WorkflowUserMetric)) *MockExecutionHelperWithRawSecrets_EmitUserMetric_Call
- func (_c *MockExecutionHelperWithRawSecrets_EmitUserMetric_Call) RunAndReturn(run func(context.Context, *v2.WorkflowUserMetric) error) *MockExecutionHelperWithRawSecrets_EmitUserMetric_Call
- type MockExecutionHelperWithRawSecrets_Expecter
- func (_e *MockExecutionHelperWithRawSecrets_Expecter) CallCapability(ctx interface{}, request interface{}) *MockExecutionHelperWithRawSecrets_CallCapability_Call
- func (_e *MockExecutionHelperWithRawSecrets_Expecter) EmitUserLog(log interface{}) *MockExecutionHelperWithRawSecrets_EmitUserLog_Call
- func (_e *MockExecutionHelperWithRawSecrets_Expecter) EmitUserMetric(ctx interface{}, metric interface{}) *MockExecutionHelperWithRawSecrets_EmitUserMetric_Call
- func (_e *MockExecutionHelperWithRawSecrets_Expecter) GetDONTime() *MockExecutionHelperWithRawSecrets_GetDONTime_Call
- func (_e *MockExecutionHelperWithRawSecrets_Expecter) GetNodeTime() *MockExecutionHelperWithRawSecrets_GetNodeTime_Call
- func (_e *MockExecutionHelperWithRawSecrets_Expecter) GetOwner() *MockExecutionHelperWithRawSecrets_GetOwner_Call
- func (_e *MockExecutionHelperWithRawSecrets_Expecter) GetRawSecrets(ctx interface{}, request interface{}, fetcher interface{}) *MockExecutionHelperWithRawSecrets_GetRawSecrets_Call
- func (_e *MockExecutionHelperWithRawSecrets_Expecter) GetSecrets(ctx interface{}, request interface{}) *MockExecutionHelperWithRawSecrets_GetSecrets_Call
- func (_e *MockExecutionHelperWithRawSecrets_Expecter) GetWorkflowExecutionID() *MockExecutionHelperWithRawSecrets_GetWorkflowExecutionID_Call
- type MockExecutionHelperWithRawSecrets_GetDONTime_Call
- func (_c *MockExecutionHelperWithRawSecrets_GetDONTime_Call) Return(_a0 time.Time, _a1 error) *MockExecutionHelperWithRawSecrets_GetDONTime_Call
- func (_c *MockExecutionHelperWithRawSecrets_GetDONTime_Call) Run(run func()) *MockExecutionHelperWithRawSecrets_GetDONTime_Call
- func (_c *MockExecutionHelperWithRawSecrets_GetDONTime_Call) RunAndReturn(run func() (time.Time, error)) *MockExecutionHelperWithRawSecrets_GetDONTime_Call
- type MockExecutionHelperWithRawSecrets_GetNodeTime_Call
- func (_c *MockExecutionHelperWithRawSecrets_GetNodeTime_Call) Return(_a0 time.Time) *MockExecutionHelperWithRawSecrets_GetNodeTime_Call
- func (_c *MockExecutionHelperWithRawSecrets_GetNodeTime_Call) Run(run func()) *MockExecutionHelperWithRawSecrets_GetNodeTime_Call
- func (_c *MockExecutionHelperWithRawSecrets_GetNodeTime_Call) RunAndReturn(run func() time.Time) *MockExecutionHelperWithRawSecrets_GetNodeTime_Call
- type MockExecutionHelperWithRawSecrets_GetOwner_Call
- func (_c *MockExecutionHelperWithRawSecrets_GetOwner_Call) Return(_a0 string) *MockExecutionHelperWithRawSecrets_GetOwner_Call
- func (_c *MockExecutionHelperWithRawSecrets_GetOwner_Call) Run(run func()) *MockExecutionHelperWithRawSecrets_GetOwner_Call
- func (_c *MockExecutionHelperWithRawSecrets_GetOwner_Call) RunAndReturn(run func() string) *MockExecutionHelperWithRawSecrets_GetOwner_Call
- type MockExecutionHelperWithRawSecrets_GetRawSecrets_Call
- func (_c *MockExecutionHelperWithRawSecrets_GetRawSecrets_Call) Return(_a0 []*vault.SecretResponse, _a1 error) *MockExecutionHelperWithRawSecrets_GetRawSecrets_Call
- func (_c *MockExecutionHelperWithRawSecrets_GetRawSecrets_Call) Run(run func(ctx context.Context, request *sdk.GetSecretsRequest, ...)) *MockExecutionHelperWithRawSecrets_GetRawSecrets_Call
- func (_c *MockExecutionHelperWithRawSecrets_GetRawSecrets_Call) RunAndReturn(...) *MockExecutionHelperWithRawSecrets_GetRawSecrets_Call
- type MockExecutionHelperWithRawSecrets_GetSecrets_Call
- func (_c *MockExecutionHelperWithRawSecrets_GetSecrets_Call) Return(_a0 []*sdk.SecretResponse, _a1 error) *MockExecutionHelperWithRawSecrets_GetSecrets_Call
- func (_c *MockExecutionHelperWithRawSecrets_GetSecrets_Call) Run(run func(ctx context.Context, request *sdk.GetSecretsRequest)) *MockExecutionHelperWithRawSecrets_GetSecrets_Call
- func (_c *MockExecutionHelperWithRawSecrets_GetSecrets_Call) RunAndReturn(...) *MockExecutionHelperWithRawSecrets_GetSecrets_Call
- type MockExecutionHelperWithRawSecrets_GetWorkflowExecutionID_Call
- func (_c *MockExecutionHelperWithRawSecrets_GetWorkflowExecutionID_Call) Return(_a0 string) *MockExecutionHelperWithRawSecrets_GetWorkflowExecutionID_Call
- func (_c *MockExecutionHelperWithRawSecrets_GetWorkflowExecutionID_Call) Run(run func()) *MockExecutionHelperWithRawSecrets_GetWorkflowExecutionID_Call
- func (_c *MockExecutionHelperWithRawSecrets_GetWorkflowExecutionID_Call) RunAndReturn(run func() string) *MockExecutionHelperWithRawSecrets_GetWorkflowExecutionID_Call
- type MockExecutionHelper_CallCapability_Call
- func (_c *MockExecutionHelper_CallCapability_Call) Return(_a0 *sdk.CapabilityResponse, _a1 error) *MockExecutionHelper_CallCapability_Call
- func (_c *MockExecutionHelper_CallCapability_Call) Run(run func(ctx context.Context, request *sdk.CapabilityRequest)) *MockExecutionHelper_CallCapability_Call
- func (_c *MockExecutionHelper_CallCapability_Call) RunAndReturn(...) *MockExecutionHelper_CallCapability_Call
- type MockExecutionHelper_EmitUserLog_Call
- func (_c *MockExecutionHelper_EmitUserLog_Call) Return(_a0 error) *MockExecutionHelper_EmitUserLog_Call
- func (_c *MockExecutionHelper_EmitUserLog_Call) Run(run func(log string)) *MockExecutionHelper_EmitUserLog_Call
- func (_c *MockExecutionHelper_EmitUserLog_Call) RunAndReturn(run func(string) error) *MockExecutionHelper_EmitUserLog_Call
- type MockExecutionHelper_EmitUserMetric_Call
- func (_c *MockExecutionHelper_EmitUserMetric_Call) Return(_a0 error) *MockExecutionHelper_EmitUserMetric_Call
- func (_c *MockExecutionHelper_EmitUserMetric_Call) Run(run func(ctx context.Context, metric *v2.WorkflowUserMetric)) *MockExecutionHelper_EmitUserMetric_Call
- func (_c *MockExecutionHelper_EmitUserMetric_Call) RunAndReturn(run func(context.Context, *v2.WorkflowUserMetric) error) *MockExecutionHelper_EmitUserMetric_Call
- type MockExecutionHelper_Expecter
- func (_e *MockExecutionHelper_Expecter) CallCapability(ctx interface{}, request interface{}) *MockExecutionHelper_CallCapability_Call
- func (_e *MockExecutionHelper_Expecter) EmitUserLog(log interface{}) *MockExecutionHelper_EmitUserLog_Call
- func (_e *MockExecutionHelper_Expecter) EmitUserMetric(ctx interface{}, metric interface{}) *MockExecutionHelper_EmitUserMetric_Call
- func (_e *MockExecutionHelper_Expecter) GetDONTime() *MockExecutionHelper_GetDONTime_Call
- func (_e *MockExecutionHelper_Expecter) GetNodeTime() *MockExecutionHelper_GetNodeTime_Call
- func (_e *MockExecutionHelper_Expecter) GetSecrets(ctx interface{}, request interface{}) *MockExecutionHelper_GetSecrets_Call
- func (_e *MockExecutionHelper_Expecter) GetWorkflowExecutionID() *MockExecutionHelper_GetWorkflowExecutionID_Call
- type MockExecutionHelper_GetDONTime_Call
- func (_c *MockExecutionHelper_GetDONTime_Call) Return(_a0 time.Time, _a1 error) *MockExecutionHelper_GetDONTime_Call
- func (_c *MockExecutionHelper_GetDONTime_Call) Run(run func()) *MockExecutionHelper_GetDONTime_Call
- func (_c *MockExecutionHelper_GetDONTime_Call) RunAndReturn(run func() (time.Time, error)) *MockExecutionHelper_GetDONTime_Call
- type MockExecutionHelper_GetNodeTime_Call
- func (_c *MockExecutionHelper_GetNodeTime_Call) Return(_a0 time.Time) *MockExecutionHelper_GetNodeTime_Call
- func (_c *MockExecutionHelper_GetNodeTime_Call) Run(run func()) *MockExecutionHelper_GetNodeTime_Call
- func (_c *MockExecutionHelper_GetNodeTime_Call) RunAndReturn(run func() time.Time) *MockExecutionHelper_GetNodeTime_Call
- type MockExecutionHelper_GetSecrets_Call
- func (_c *MockExecutionHelper_GetSecrets_Call) Return(_a0 []*sdk.SecretResponse, _a1 error) *MockExecutionHelper_GetSecrets_Call
- func (_c *MockExecutionHelper_GetSecrets_Call) Run(run func(ctx context.Context, request *sdk.GetSecretsRequest)) *MockExecutionHelper_GetSecrets_Call
- func (_c *MockExecutionHelper_GetSecrets_Call) RunAndReturn(...) *MockExecutionHelper_GetSecrets_Call
- type MockExecutionHelper_GetWorkflowExecutionID_Call
- func (_c *MockExecutionHelper_GetWorkflowExecutionID_Call) Return(_a0 string) *MockExecutionHelper_GetWorkflowExecutionID_Call
- func (_c *MockExecutionHelper_GetWorkflowExecutionID_Call) Run(run func()) *MockExecutionHelper_GetWorkflowExecutionID_Call
- func (_c *MockExecutionHelper_GetWorkflowExecutionID_Call) RunAndReturn(run func() string) *MockExecutionHelper_GetWorkflowExecutionID_Call
- type Module
- type Module_Close_Call
- type Module_Execute_Call
- type Module_Expecter
- type Module_IsLegacyDAG_Call
- type Module_Start_Call
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MockExecutionHelper ¶
MockExecutionHelper is an autogenerated mock type for the ExecutionHelper type
func NewMockExecutionHelper ¶
func NewMockExecutionHelper(t interface {
mock.TestingT
Cleanup(func())
}) *MockExecutionHelper
NewMockExecutionHelper creates a new instance of MockExecutionHelper. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*MockExecutionHelper) CallCapability ¶
func (_m *MockExecutionHelper) CallCapability(ctx context.Context, request *sdk.CapabilityRequest) (*sdk.CapabilityResponse, error)
CallCapability provides a mock function with given fields: ctx, request
func (*MockExecutionHelper) EXPECT ¶
func (_m *MockExecutionHelper) EXPECT() *MockExecutionHelper_Expecter
func (*MockExecutionHelper) EmitUserLog ¶
func (_m *MockExecutionHelper) EmitUserLog(log string) error
EmitUserLog provides a mock function with given fields: log
func (*MockExecutionHelper) EmitUserMetric ¶
func (_m *MockExecutionHelper) EmitUserMetric(ctx context.Context, metric *v2.WorkflowUserMetric) error
EmitUserMetric provides a mock function with given fields: ctx, metric
func (*MockExecutionHelper) GetDONTime ¶
func (_m *MockExecutionHelper) GetDONTime() (time.Time, error)
GetDONTime provides a mock function with no fields
func (*MockExecutionHelper) GetNodeTime ¶
func (_m *MockExecutionHelper) GetNodeTime() time.Time
GetNodeTime provides a mock function with no fields
func (*MockExecutionHelper) GetSecrets ¶
func (_m *MockExecutionHelper) GetSecrets(ctx context.Context, request *sdk.GetSecretsRequest) ([]*sdk.SecretResponse, error)
GetSecrets provides a mock function with given fields: ctx, request
func (*MockExecutionHelper) GetWorkflowExecutionID ¶
func (_m *MockExecutionHelper) GetWorkflowExecutionID() string
GetWorkflowExecutionID provides a mock function with no fields
type MockExecutionHelperWithRawSecrets ¶
MockExecutionHelperWithRawSecrets is an autogenerated mock type for the ExecutionHelperWithRawSecrets type
func NewMockExecutionHelperWithRawSecrets ¶
func NewMockExecutionHelperWithRawSecrets(t interface {
mock.TestingT
Cleanup(func())
}) *MockExecutionHelperWithRawSecrets
NewMockExecutionHelperWithRawSecrets creates a new instance of MockExecutionHelperWithRawSecrets. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*MockExecutionHelperWithRawSecrets) CallCapability ¶
func (_m *MockExecutionHelperWithRawSecrets) CallCapability(ctx context.Context, request *sdk.CapabilityRequest) (*sdk.CapabilityResponse, error)
CallCapability provides a mock function with given fields: ctx, request
func (*MockExecutionHelperWithRawSecrets) EXPECT ¶
func (_m *MockExecutionHelperWithRawSecrets) EXPECT() *MockExecutionHelperWithRawSecrets_Expecter
func (*MockExecutionHelperWithRawSecrets) EmitUserLog ¶
func (_m *MockExecutionHelperWithRawSecrets) EmitUserLog(log string) error
EmitUserLog provides a mock function with given fields: log
func (*MockExecutionHelperWithRawSecrets) EmitUserMetric ¶
func (_m *MockExecutionHelperWithRawSecrets) EmitUserMetric(ctx context.Context, metric *v2.WorkflowUserMetric) error
EmitUserMetric provides a mock function with given fields: ctx, metric
func (*MockExecutionHelperWithRawSecrets) GetDONTime ¶
func (_m *MockExecutionHelperWithRawSecrets) GetDONTime() (time.Time, error)
GetDONTime provides a mock function with no fields
func (*MockExecutionHelperWithRawSecrets) GetNodeTime ¶
func (_m *MockExecutionHelperWithRawSecrets) GetNodeTime() time.Time
GetNodeTime provides a mock function with no fields
func (*MockExecutionHelperWithRawSecrets) GetOwner ¶
func (_m *MockExecutionHelperWithRawSecrets) GetOwner() string
GetOwner provides a mock function with no fields
func (*MockExecutionHelperWithRawSecrets) GetRawSecrets ¶
func (_m *MockExecutionHelperWithRawSecrets) GetRawSecrets(ctx context.Context, request *sdk.GetSecretsRequest, fetcher host.EncryptionKeyFetcher) ([]*vault.SecretResponse, error)
GetRawSecrets provides a mock function with given fields: ctx, request, fetcher
func (*MockExecutionHelperWithRawSecrets) GetSecrets ¶
func (_m *MockExecutionHelperWithRawSecrets) GetSecrets(ctx context.Context, request *sdk.GetSecretsRequest) ([]*sdk.SecretResponse, error)
GetSecrets provides a mock function with given fields: ctx, request
func (*MockExecutionHelperWithRawSecrets) GetWorkflowExecutionID ¶
func (_m *MockExecutionHelperWithRawSecrets) GetWorkflowExecutionID() string
GetWorkflowExecutionID provides a mock function with no fields
type MockExecutionHelperWithRawSecrets_CallCapability_Call ¶
MockExecutionHelperWithRawSecrets_CallCapability_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'CallCapability'
func (*MockExecutionHelperWithRawSecrets_CallCapability_Call) Return ¶
func (_c *MockExecutionHelperWithRawSecrets_CallCapability_Call) Return(_a0 *sdk.CapabilityResponse, _a1 error) *MockExecutionHelperWithRawSecrets_CallCapability_Call
func (*MockExecutionHelperWithRawSecrets_CallCapability_Call) Run ¶
func (_c *MockExecutionHelperWithRawSecrets_CallCapability_Call) Run(run func(ctx context.Context, request *sdk.CapabilityRequest)) *MockExecutionHelperWithRawSecrets_CallCapability_Call
func (*MockExecutionHelperWithRawSecrets_CallCapability_Call) RunAndReturn ¶
func (_c *MockExecutionHelperWithRawSecrets_CallCapability_Call) RunAndReturn(run func(context.Context, *sdk.CapabilityRequest) (*sdk.CapabilityResponse, error)) *MockExecutionHelperWithRawSecrets_CallCapability_Call
type MockExecutionHelperWithRawSecrets_EmitUserLog_Call ¶
MockExecutionHelperWithRawSecrets_EmitUserLog_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'EmitUserLog'
func (*MockExecutionHelperWithRawSecrets_EmitUserLog_Call) Run ¶
func (_c *MockExecutionHelperWithRawSecrets_EmitUserLog_Call) Run(run func(log string)) *MockExecutionHelperWithRawSecrets_EmitUserLog_Call
func (*MockExecutionHelperWithRawSecrets_EmitUserLog_Call) RunAndReturn ¶
func (_c *MockExecutionHelperWithRawSecrets_EmitUserLog_Call) RunAndReturn(run func(string) error) *MockExecutionHelperWithRawSecrets_EmitUserLog_Call
type MockExecutionHelperWithRawSecrets_EmitUserMetric_Call ¶
MockExecutionHelperWithRawSecrets_EmitUserMetric_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'EmitUserMetric'
func (*MockExecutionHelperWithRawSecrets_EmitUserMetric_Call) Run ¶
func (_c *MockExecutionHelperWithRawSecrets_EmitUserMetric_Call) Run(run func(ctx context.Context, metric *v2.WorkflowUserMetric)) *MockExecutionHelperWithRawSecrets_EmitUserMetric_Call
func (*MockExecutionHelperWithRawSecrets_EmitUserMetric_Call) RunAndReturn ¶
func (_c *MockExecutionHelperWithRawSecrets_EmitUserMetric_Call) RunAndReturn(run func(context.Context, *v2.WorkflowUserMetric) error) *MockExecutionHelperWithRawSecrets_EmitUserMetric_Call
type MockExecutionHelperWithRawSecrets_Expecter ¶
type MockExecutionHelperWithRawSecrets_Expecter struct {
// contains filtered or unexported fields
}
func (*MockExecutionHelperWithRawSecrets_Expecter) CallCapability ¶
func (_e *MockExecutionHelperWithRawSecrets_Expecter) CallCapability(ctx interface{}, request interface{}) *MockExecutionHelperWithRawSecrets_CallCapability_Call
CallCapability is a helper method to define mock.On call
- ctx context.Context
- request *sdk.CapabilityRequest
func (*MockExecutionHelperWithRawSecrets_Expecter) EmitUserLog ¶
func (_e *MockExecutionHelperWithRawSecrets_Expecter) EmitUserLog(log interface{}) *MockExecutionHelperWithRawSecrets_EmitUserLog_Call
EmitUserLog is a helper method to define mock.On call
- log string
func (*MockExecutionHelperWithRawSecrets_Expecter) EmitUserMetric ¶
func (_e *MockExecutionHelperWithRawSecrets_Expecter) EmitUserMetric(ctx interface{}, metric interface{}) *MockExecutionHelperWithRawSecrets_EmitUserMetric_Call
EmitUserMetric is a helper method to define mock.On call
- ctx context.Context
- metric *v2.WorkflowUserMetric
func (*MockExecutionHelperWithRawSecrets_Expecter) GetDONTime ¶
func (_e *MockExecutionHelperWithRawSecrets_Expecter) GetDONTime() *MockExecutionHelperWithRawSecrets_GetDONTime_Call
GetDONTime is a helper method to define mock.On call
func (*MockExecutionHelperWithRawSecrets_Expecter) GetNodeTime ¶
func (_e *MockExecutionHelperWithRawSecrets_Expecter) GetNodeTime() *MockExecutionHelperWithRawSecrets_GetNodeTime_Call
GetNodeTime is a helper method to define mock.On call
func (*MockExecutionHelperWithRawSecrets_Expecter) GetOwner ¶
func (_e *MockExecutionHelperWithRawSecrets_Expecter) GetOwner() *MockExecutionHelperWithRawSecrets_GetOwner_Call
GetOwner is a helper method to define mock.On call
func (*MockExecutionHelperWithRawSecrets_Expecter) GetRawSecrets ¶
func (_e *MockExecutionHelperWithRawSecrets_Expecter) GetRawSecrets(ctx interface{}, request interface{}, fetcher interface{}) *MockExecutionHelperWithRawSecrets_GetRawSecrets_Call
GetRawSecrets is a helper method to define mock.On call
- ctx context.Context
- request *sdk.GetSecretsRequest
- fetcher host.EncryptionKeyFetcher
func (*MockExecutionHelperWithRawSecrets_Expecter) GetSecrets ¶
func (_e *MockExecutionHelperWithRawSecrets_Expecter) GetSecrets(ctx interface{}, request interface{}) *MockExecutionHelperWithRawSecrets_GetSecrets_Call
GetSecrets is a helper method to define mock.On call
- ctx context.Context
- request *sdk.GetSecretsRequest
func (*MockExecutionHelperWithRawSecrets_Expecter) GetWorkflowExecutionID ¶
func (_e *MockExecutionHelperWithRawSecrets_Expecter) GetWorkflowExecutionID() *MockExecutionHelperWithRawSecrets_GetWorkflowExecutionID_Call
GetWorkflowExecutionID is a helper method to define mock.On call
type MockExecutionHelperWithRawSecrets_GetDONTime_Call ¶
MockExecutionHelperWithRawSecrets_GetDONTime_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetDONTime'
func (*MockExecutionHelperWithRawSecrets_GetDONTime_Call) Return ¶
func (_c *MockExecutionHelperWithRawSecrets_GetDONTime_Call) Return(_a0 time.Time, _a1 error) *MockExecutionHelperWithRawSecrets_GetDONTime_Call
func (*MockExecutionHelperWithRawSecrets_GetDONTime_Call) Run ¶
func (_c *MockExecutionHelperWithRawSecrets_GetDONTime_Call) Run(run func()) *MockExecutionHelperWithRawSecrets_GetDONTime_Call
func (*MockExecutionHelperWithRawSecrets_GetDONTime_Call) RunAndReturn ¶
func (_c *MockExecutionHelperWithRawSecrets_GetDONTime_Call) RunAndReturn(run func() (time.Time, error)) *MockExecutionHelperWithRawSecrets_GetDONTime_Call
type MockExecutionHelperWithRawSecrets_GetNodeTime_Call ¶
MockExecutionHelperWithRawSecrets_GetNodeTime_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetNodeTime'
func (*MockExecutionHelperWithRawSecrets_GetNodeTime_Call) Return ¶
func (_c *MockExecutionHelperWithRawSecrets_GetNodeTime_Call) Return(_a0 time.Time) *MockExecutionHelperWithRawSecrets_GetNodeTime_Call
func (*MockExecutionHelperWithRawSecrets_GetNodeTime_Call) Run ¶
func (_c *MockExecutionHelperWithRawSecrets_GetNodeTime_Call) Run(run func()) *MockExecutionHelperWithRawSecrets_GetNodeTime_Call
func (*MockExecutionHelperWithRawSecrets_GetNodeTime_Call) RunAndReturn ¶
func (_c *MockExecutionHelperWithRawSecrets_GetNodeTime_Call) RunAndReturn(run func() time.Time) *MockExecutionHelperWithRawSecrets_GetNodeTime_Call
type MockExecutionHelperWithRawSecrets_GetOwner_Call ¶
MockExecutionHelperWithRawSecrets_GetOwner_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetOwner'
func (*MockExecutionHelperWithRawSecrets_GetOwner_Call) Return ¶
func (_c *MockExecutionHelperWithRawSecrets_GetOwner_Call) Return(_a0 string) *MockExecutionHelperWithRawSecrets_GetOwner_Call
func (*MockExecutionHelperWithRawSecrets_GetOwner_Call) Run ¶
func (_c *MockExecutionHelperWithRawSecrets_GetOwner_Call) Run(run func()) *MockExecutionHelperWithRawSecrets_GetOwner_Call
func (*MockExecutionHelperWithRawSecrets_GetOwner_Call) RunAndReturn ¶
func (_c *MockExecutionHelperWithRawSecrets_GetOwner_Call) RunAndReturn(run func() string) *MockExecutionHelperWithRawSecrets_GetOwner_Call
type MockExecutionHelperWithRawSecrets_GetRawSecrets_Call ¶
MockExecutionHelperWithRawSecrets_GetRawSecrets_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetRawSecrets'
func (*MockExecutionHelperWithRawSecrets_GetRawSecrets_Call) Return ¶
func (_c *MockExecutionHelperWithRawSecrets_GetRawSecrets_Call) Return(_a0 []*vault.SecretResponse, _a1 error) *MockExecutionHelperWithRawSecrets_GetRawSecrets_Call
func (*MockExecutionHelperWithRawSecrets_GetRawSecrets_Call) Run ¶
func (_c *MockExecutionHelperWithRawSecrets_GetRawSecrets_Call) Run(run func(ctx context.Context, request *sdk.GetSecretsRequest, fetcher host.EncryptionKeyFetcher)) *MockExecutionHelperWithRawSecrets_GetRawSecrets_Call
func (*MockExecutionHelperWithRawSecrets_GetRawSecrets_Call) RunAndReturn ¶
func (_c *MockExecutionHelperWithRawSecrets_GetRawSecrets_Call) RunAndReturn(run func(context.Context, *sdk.GetSecretsRequest, host.EncryptionKeyFetcher) ([]*vault.SecretResponse, error)) *MockExecutionHelperWithRawSecrets_GetRawSecrets_Call
type MockExecutionHelperWithRawSecrets_GetSecrets_Call ¶
MockExecutionHelperWithRawSecrets_GetSecrets_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetSecrets'
func (*MockExecutionHelperWithRawSecrets_GetSecrets_Call) Return ¶
func (_c *MockExecutionHelperWithRawSecrets_GetSecrets_Call) Return(_a0 []*sdk.SecretResponse, _a1 error) *MockExecutionHelperWithRawSecrets_GetSecrets_Call
func (*MockExecutionHelperWithRawSecrets_GetSecrets_Call) Run ¶
func (_c *MockExecutionHelperWithRawSecrets_GetSecrets_Call) Run(run func(ctx context.Context, request *sdk.GetSecretsRequest)) *MockExecutionHelperWithRawSecrets_GetSecrets_Call
func (*MockExecutionHelperWithRawSecrets_GetSecrets_Call) RunAndReturn ¶
func (_c *MockExecutionHelperWithRawSecrets_GetSecrets_Call) RunAndReturn(run func(context.Context, *sdk.GetSecretsRequest) ([]*sdk.SecretResponse, error)) *MockExecutionHelperWithRawSecrets_GetSecrets_Call
type MockExecutionHelperWithRawSecrets_GetWorkflowExecutionID_Call ¶
MockExecutionHelperWithRawSecrets_GetWorkflowExecutionID_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetWorkflowExecutionID'
func (*MockExecutionHelperWithRawSecrets_GetWorkflowExecutionID_Call) RunAndReturn ¶
func (_c *MockExecutionHelperWithRawSecrets_GetWorkflowExecutionID_Call) RunAndReturn(run func() string) *MockExecutionHelperWithRawSecrets_GetWorkflowExecutionID_Call
type MockExecutionHelper_CallCapability_Call ¶
MockExecutionHelper_CallCapability_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'CallCapability'
func (*MockExecutionHelper_CallCapability_Call) Return ¶
func (_c *MockExecutionHelper_CallCapability_Call) Return(_a0 *sdk.CapabilityResponse, _a1 error) *MockExecutionHelper_CallCapability_Call
func (*MockExecutionHelper_CallCapability_Call) Run ¶
func (_c *MockExecutionHelper_CallCapability_Call) Run(run func(ctx context.Context, request *sdk.CapabilityRequest)) *MockExecutionHelper_CallCapability_Call
func (*MockExecutionHelper_CallCapability_Call) RunAndReturn ¶
func (_c *MockExecutionHelper_CallCapability_Call) RunAndReturn(run func(context.Context, *sdk.CapabilityRequest) (*sdk.CapabilityResponse, error)) *MockExecutionHelper_CallCapability_Call
type MockExecutionHelper_EmitUserLog_Call ¶
MockExecutionHelper_EmitUserLog_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'EmitUserLog'
func (*MockExecutionHelper_EmitUserLog_Call) Return ¶
func (_c *MockExecutionHelper_EmitUserLog_Call) Return(_a0 error) *MockExecutionHelper_EmitUserLog_Call
func (*MockExecutionHelper_EmitUserLog_Call) Run ¶
func (_c *MockExecutionHelper_EmitUserLog_Call) Run(run func(log string)) *MockExecutionHelper_EmitUserLog_Call
func (*MockExecutionHelper_EmitUserLog_Call) RunAndReturn ¶
func (_c *MockExecutionHelper_EmitUserLog_Call) RunAndReturn(run func(string) error) *MockExecutionHelper_EmitUserLog_Call
type MockExecutionHelper_EmitUserMetric_Call ¶
MockExecutionHelper_EmitUserMetric_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'EmitUserMetric'
func (*MockExecutionHelper_EmitUserMetric_Call) Return ¶
func (_c *MockExecutionHelper_EmitUserMetric_Call) Return(_a0 error) *MockExecutionHelper_EmitUserMetric_Call
func (*MockExecutionHelper_EmitUserMetric_Call) Run ¶
func (_c *MockExecutionHelper_EmitUserMetric_Call) Run(run func(ctx context.Context, metric *v2.WorkflowUserMetric)) *MockExecutionHelper_EmitUserMetric_Call
func (*MockExecutionHelper_EmitUserMetric_Call) RunAndReturn ¶
func (_c *MockExecutionHelper_EmitUserMetric_Call) RunAndReturn(run func(context.Context, *v2.WorkflowUserMetric) error) *MockExecutionHelper_EmitUserMetric_Call
type MockExecutionHelper_Expecter ¶
type MockExecutionHelper_Expecter struct {
// contains filtered or unexported fields
}
func (*MockExecutionHelper_Expecter) CallCapability ¶
func (_e *MockExecutionHelper_Expecter) CallCapability(ctx interface{}, request interface{}) *MockExecutionHelper_CallCapability_Call
CallCapability is a helper method to define mock.On call
- ctx context.Context
- request *sdk.CapabilityRequest
func (*MockExecutionHelper_Expecter) EmitUserLog ¶
func (_e *MockExecutionHelper_Expecter) EmitUserLog(log interface{}) *MockExecutionHelper_EmitUserLog_Call
EmitUserLog is a helper method to define mock.On call
- log string
func (*MockExecutionHelper_Expecter) EmitUserMetric ¶
func (_e *MockExecutionHelper_Expecter) EmitUserMetric(ctx interface{}, metric interface{}) *MockExecutionHelper_EmitUserMetric_Call
EmitUserMetric is a helper method to define mock.On call
- ctx context.Context
- metric *v2.WorkflowUserMetric
func (*MockExecutionHelper_Expecter) GetDONTime ¶
func (_e *MockExecutionHelper_Expecter) GetDONTime() *MockExecutionHelper_GetDONTime_Call
GetDONTime is a helper method to define mock.On call
func (*MockExecutionHelper_Expecter) GetNodeTime ¶
func (_e *MockExecutionHelper_Expecter) GetNodeTime() *MockExecutionHelper_GetNodeTime_Call
GetNodeTime is a helper method to define mock.On call
func (*MockExecutionHelper_Expecter) GetSecrets ¶
func (_e *MockExecutionHelper_Expecter) GetSecrets(ctx interface{}, request interface{}) *MockExecutionHelper_GetSecrets_Call
GetSecrets is a helper method to define mock.On call
- ctx context.Context
- request *sdk.GetSecretsRequest
func (*MockExecutionHelper_Expecter) GetWorkflowExecutionID ¶
func (_e *MockExecutionHelper_Expecter) GetWorkflowExecutionID() *MockExecutionHelper_GetWorkflowExecutionID_Call
GetWorkflowExecutionID is a helper method to define mock.On call
type MockExecutionHelper_GetDONTime_Call ¶
MockExecutionHelper_GetDONTime_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetDONTime'
func (*MockExecutionHelper_GetDONTime_Call) Return ¶
func (_c *MockExecutionHelper_GetDONTime_Call) Return(_a0 time.Time, _a1 error) *MockExecutionHelper_GetDONTime_Call
func (*MockExecutionHelper_GetDONTime_Call) Run ¶
func (_c *MockExecutionHelper_GetDONTime_Call) Run(run func()) *MockExecutionHelper_GetDONTime_Call
func (*MockExecutionHelper_GetDONTime_Call) RunAndReturn ¶
func (_c *MockExecutionHelper_GetDONTime_Call) RunAndReturn(run func() (time.Time, error)) *MockExecutionHelper_GetDONTime_Call
type MockExecutionHelper_GetNodeTime_Call ¶
MockExecutionHelper_GetNodeTime_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetNodeTime'
func (*MockExecutionHelper_GetNodeTime_Call) Return ¶
func (_c *MockExecutionHelper_GetNodeTime_Call) Return(_a0 time.Time) *MockExecutionHelper_GetNodeTime_Call
func (*MockExecutionHelper_GetNodeTime_Call) Run ¶
func (_c *MockExecutionHelper_GetNodeTime_Call) Run(run func()) *MockExecutionHelper_GetNodeTime_Call
func (*MockExecutionHelper_GetNodeTime_Call) RunAndReturn ¶
func (_c *MockExecutionHelper_GetNodeTime_Call) RunAndReturn(run func() time.Time) *MockExecutionHelper_GetNodeTime_Call
type MockExecutionHelper_GetSecrets_Call ¶
MockExecutionHelper_GetSecrets_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetSecrets'
func (*MockExecutionHelper_GetSecrets_Call) Return ¶
func (_c *MockExecutionHelper_GetSecrets_Call) Return(_a0 []*sdk.SecretResponse, _a1 error) *MockExecutionHelper_GetSecrets_Call
func (*MockExecutionHelper_GetSecrets_Call) Run ¶
func (_c *MockExecutionHelper_GetSecrets_Call) Run(run func(ctx context.Context, request *sdk.GetSecretsRequest)) *MockExecutionHelper_GetSecrets_Call
func (*MockExecutionHelper_GetSecrets_Call) RunAndReturn ¶
func (_c *MockExecutionHelper_GetSecrets_Call) RunAndReturn(run func(context.Context, *sdk.GetSecretsRequest) ([]*sdk.SecretResponse, error)) *MockExecutionHelper_GetSecrets_Call
type MockExecutionHelper_GetWorkflowExecutionID_Call ¶
MockExecutionHelper_GetWorkflowExecutionID_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetWorkflowExecutionID'
func (*MockExecutionHelper_GetWorkflowExecutionID_Call) Return ¶
func (_c *MockExecutionHelper_GetWorkflowExecutionID_Call) Return(_a0 string) *MockExecutionHelper_GetWorkflowExecutionID_Call
func (*MockExecutionHelper_GetWorkflowExecutionID_Call) Run ¶
func (_c *MockExecutionHelper_GetWorkflowExecutionID_Call) Run(run func()) *MockExecutionHelper_GetWorkflowExecutionID_Call
func (*MockExecutionHelper_GetWorkflowExecutionID_Call) RunAndReturn ¶
func (_c *MockExecutionHelper_GetWorkflowExecutionID_Call) RunAndReturn(run func() string) *MockExecutionHelper_GetWorkflowExecutionID_Call
type Module ¶
Module is an autogenerated mock type for the Module type
func NewModule ¶
NewModule creates a new instance of Module. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*Module) EXPECT ¶
func (_m *Module) EXPECT() *Module_Expecter
func (*Module) Execute ¶
func (_m *Module) Execute(ctx context.Context, request *sdk.ExecuteRequest, handler host.ExecutionHelper) (*sdk.ExecutionResult, error)
Execute provides a mock function with given fields: ctx, request, handler
func (*Module) IsLegacyDAG ¶
IsLegacyDAG provides a mock function with no fields
type Module_Close_Call ¶
Module_Close_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Close'
func (*Module_Close_Call) Return ¶
func (_c *Module_Close_Call) Return() *Module_Close_Call
func (*Module_Close_Call) Run ¶
func (_c *Module_Close_Call) Run(run func()) *Module_Close_Call
func (*Module_Close_Call) RunAndReturn ¶
func (_c *Module_Close_Call) RunAndReturn(run func()) *Module_Close_Call
type Module_Execute_Call ¶
Module_Execute_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Execute'
func (*Module_Execute_Call) Return ¶
func (_c *Module_Execute_Call) Return(_a0 *sdk.ExecutionResult, _a1 error) *Module_Execute_Call
func (*Module_Execute_Call) Run ¶
func (_c *Module_Execute_Call) Run(run func(ctx context.Context, request *sdk.ExecuteRequest, handler host.ExecutionHelper)) *Module_Execute_Call
func (*Module_Execute_Call) RunAndReturn ¶
func (_c *Module_Execute_Call) RunAndReturn(run func(context.Context, *sdk.ExecuteRequest, host.ExecutionHelper) (*sdk.ExecutionResult, error)) *Module_Execute_Call
type Module_Expecter ¶
type Module_Expecter struct {
// contains filtered or unexported fields
}
func (*Module_Expecter) Close ¶
func (_e *Module_Expecter) Close() *Module_Close_Call
Close is a helper method to define mock.On call
func (*Module_Expecter) Execute ¶
func (_e *Module_Expecter) Execute(ctx interface{}, request interface{}, handler interface{}) *Module_Execute_Call
Execute is a helper method to define mock.On call
- ctx context.Context
- request *sdk.ExecuteRequest
- handler host.ExecutionHelper
func (*Module_Expecter) IsLegacyDAG ¶
func (_e *Module_Expecter) IsLegacyDAG() *Module_IsLegacyDAG_Call
IsLegacyDAG is a helper method to define mock.On call
func (*Module_Expecter) Start ¶
func (_e *Module_Expecter) Start() *Module_Start_Call
Start is a helper method to define mock.On call
type Module_IsLegacyDAG_Call ¶
Module_IsLegacyDAG_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'IsLegacyDAG'
func (*Module_IsLegacyDAG_Call) Return ¶
func (_c *Module_IsLegacyDAG_Call) Return(_a0 bool) *Module_IsLegacyDAG_Call
func (*Module_IsLegacyDAG_Call) Run ¶
func (_c *Module_IsLegacyDAG_Call) Run(run func()) *Module_IsLegacyDAG_Call
func (*Module_IsLegacyDAG_Call) RunAndReturn ¶
func (_c *Module_IsLegacyDAG_Call) RunAndReturn(run func() bool) *Module_IsLegacyDAG_Call
type Module_Start_Call ¶
Module_Start_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Start'
func (*Module_Start_Call) Return ¶
func (_c *Module_Start_Call) Return() *Module_Start_Call
func (*Module_Start_Call) Run ¶
func (_c *Module_Start_Call) Run(run func()) *Module_Start_Call
func (*Module_Start_Call) RunAndReturn ¶
func (_c *Module_Start_Call) RunAndReturn(run func()) *Module_Start_Call